@@ -141,6 +141,8 @@
 #define OMWEATHER_SIGNAL_RELOAD_CONFIG_PATH "/org/maemo/omweather/reload_config"
 #define OMWEATHER_RELOAD_CONFIG "reload_config"
 #define OMWEATHER_RELOAD_PLUGIN "reload_plugin"
+#define MCE_MATCH_RULE "type='signal',interface='" MCE_SIGNAL_IF \
+                        "',member='" MCE_DEVICE_ORIENTATION_SIG "'"
 
 /*******************************************************************************/
 enum { AUTOUPDATE, CHANGE_DAY_PART, DBUSINITEVENT, UPDATE_AFTER_CONNECTED,
@@ -520,6 +522,7 @@ typedef struct OMWeatherApplet{
 #endif
 #ifdef OS2009
     gboolean    portrait_position;
+    gboolean    popup_portrait_position;
     HDHomePluginItem *home_window;
 #endif
 #if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
